// https://nuxt.com/docs/api/configuration/nuxt-config
import 'dotenv/config';

export default defineNuxtConfig({
  modules: [
    '@nuxtjs/tailwindcss',
    '@nuxt/fonts',
    '@pinia/nuxt',
    '@nuxt/eslint',
    '@nuxt/image',
  ],
  ssr: true,
  imports: {
    dirs: ['types/*.ts', 'store/*.ts', 'types/**/*.ts'],
  },
  devtools: { enabled: true },
  css: ['~/assets/main.css'],
  runtimeConfig: {
    public: {
      cdn_url: process.env.CDN_URL,
    },
  },
  routeRules: {
    '/': { prerender: true },
  },
  compatibilityDate: '2024-11-01',
  eslint: {
    config: {
      stylistic: {
        indent: 2,
        semi: true,
        quotes: 'single',
        jsx: false,
      },
    },
  },
  image: {
    providers: {
      selfhost: {
        name: 'selfhost',
        provider: '~/providers/selfhost.ts',
        options: {
          baseUrl: process.env.CDN_URL,
        },
      },
    },
    provider: 'selfhost',
  },
});
